import React, { useState, useEffect } from 'react';
import styles from './incident.less';
import {
    Form,
    Card,
    Space,
    Table,
    Popconfirm,
    Spin,
    Tooltip,
    notification,
    Tree,
    Button,
} from 'antd';

import {
    DoubleLeftOutlined,
    DoubleRightOutlined,
    PlusSquareFilled,
    RightOutlined,
    EditTwoTone,
    DeleteOutlined,
    OrderedListOutlined,
    ApartmentOutlined,
    DesktopOutlined
} from '@ant-design/icons';
import classnames from 'classnames';
const incident = () => {
    const [treeLoading, setTreeLoading] = useState(false);
    const [tableLoading, setTableLoading] = useState(false);
    const [treeVisible, setTreeVisible] = useState(true); // 左边列表是否可见
    const [treeData, setTreeData] = useState([]); // 事件表数据
    const [tableData, setTableData] = useState([]); // 事件表

    // const setRowClassName = record =>
    // record.userID === selectColor.userID ? styles.clickRowStyle : '';
    const columns = [
        {
            title: '事件名称',

        },
        {
            title: '事件主表'
        }
        ,
        {
            title: '编码'
        }
        ,
        {
            title: '摘要字段'
        }
        ,
        {
            title: '权限'
        }
        ,
        {
            title: '流程'
        }
        ,
        {
            title: '上报'
        }
        ,
        {
            title: '上报字段'
        }
        ,
        {
            title: '显示字段'
        }

        ,
        {
            title: '编辑',
            render: record => {
                if (!record) {
                    return '-';
                }
                return record;
            },
        }
        ,
        {
            title: '编辑字段'
        }
        ,
        {
            title: '上报方式'
        }
        ,
        {
            title: '置顶条件',
            render: record => {
                if (!record) {
                    return '-';
                }
                return record;
            },
        }
        ,
        {
            title: '接口配置',
            render: record => {
                if (!record) {
                    return '-';
                }
                return record;
            },
        }
        ,
        {
            title: '操作',
            aligin: 'center',
            render: record => {
                <Space size="middle">
                    <Tooltip title="编辑用户">
                        <EditTwoTone
                            onClick={() => editEventType(record)}
                            style={{ fontSize: '16px' }}
                        />
                    </Tooltip>
                    <Tooltip title="删除">
                        <Popconfirm
                            placement="bottomRight"
                            title={
                                <p>
                                    即将删除事件类型{' '}
                                    <span className={styles.redText}>
                                        {voca.stripTags(record.loginName)}
                                    </span>
                                    ，是否确认删除？
                                </p>
                            }
                            okText="确认"
                            cancelText="取消"
                            onConfirm={() => deleteEventType(record)}
                        >
                            <DeleteOutlined style={{ fontSize: '16px', color: '#e86060' }} />
                        </Popconfirm>
                    </Tooltip>
                </Space>
            }

        }
    ]
    //添加事件
    const addIncident = () => {

    }
    //修改事件类型
    const editEventType = () =>{

    }
    //删除事件类型
    const deleteEventType = () =>{

    }
    const onSelect = () => {

    }
    const sort = () => {

    }
    const process = () => {

    }
    const auxiliaryView = () => {

    }
    return (
        <div className={styles.incidentContainer}>
            <div className={styles.contentContainers}>
                {/*左侧事件树 */}
                <Spin spinning={treeLoading} tip="loading...">
                    <Card
                        className={classnames({
                            [styles.orgContainer]: true,
                            [styles.orgContainerHide]: !treeVisible,
                        })}
                    >
                        <div>
                            <span
                                style={{
                                    fontSize: '15px ',
                                    fontWeight: 'bold',
                                    marginLeft: '15px'
                                }}
                            >
                                事件列表
                            </span>
                            <Tooltip title="添加事件类型">
                                <PlusSquareFilled
                                    onClick={() => addIncident()}
                                    style={{
                                        color: '#1890FF',
                                        fontSize: '25px',
                                        verticalAlign: 'middle',
                                        marginLeft: '60%'
                                    }}
                                />
                            </Tooltip>
                            <hr style={{ width: '95%', color: '#eeecec', marginLeft: '15px' }} />
                            <Tree
                                onSelect={onSelect}
                                height={
                                    treeData.length && treeData.length > 30
                                        ? treeData.length * 15 + 30
                                        : 1000
                                }

                            />
                        </div>
                        <div className={styles.switcher}>
                            {treeVisible && (
                                <Tooltip title="隐藏机构列表">
                                    <DoubleLeftOutlined onClick={() => setTreeVisible(false)} />
                                </Tooltip>
                            )}
                            {!treeVisible && (
                                <Tooltip title="显示机构列表">
                                    <DoubleRightOutlined onClick={() => setTreeVisible(true)} />
                                </Tooltip>
                            )}
                        </div>
                    </Card>
                </Spin>
                {/*右侧 */}
                <div
                    className={classnames({
                        [styles.userContainer]: true,
                        [styles.userContainerHide]: !treeVisible,
                    })}
                >
                    <div style={{ height: '50px' }}>
                        <span style={{ float: 'right', marginRight: '10px' }}>
                            <Button icon={<OrderedListOutlined className={styles.icon} />} onClick={sort} style={{ marginLeft: '30px', verticalAlign: 'middle', marginTop: '10px' }}>
                                调序
                            </Button>
                            <Button icon={<ApartmentOutlined className={styles.icon} />} onClick={process} style={{ marginLeft: '30px', verticalAlign: 'middle', marginTop: '10px' }}>
                                受理流程
                            </Button>
                            <Button icon={<DesktopOutlined className={styles.icon} />} onClick={auxiliaryView} style={{ marginLeft: '30px', verticalAlign: 'middle', marginTop: '10px' }}>
                                辅助视图
                            </Button>
                        </span>
                    </div>
                    <Table
                        // rowClassName={setRowClassName}
                        size="small"
                        // rowKey={}
                        bordered
                        columns={columns}
                        dataSource={tableData}
                        loading={tableLoading}
                        scroll={{ x: 'max-content', y: 'calc(100vh - 210px)' }}
                        pagination={{
                            showTotal: (total, range) =>
                                `第${range[0]}-${range[1]} 条/共 ${total} 条`,
                            pageSizeOptions: [10, 20, 50, 100],
                            defaultPageSize: 20,
                            showQuickJumper: true,
                            showSizeChanger: true,
                        }}
                    />
                </div>
            </div>
        </div>
    )
};

export default incident;